# Welcome to kangeo


[![image](https://img.shields.io/pypi/v/kangeo.svg)](https://pypi.python.org/pypi/kangeo)


**A geospatial python package**


-   Free software: MIT License
-   Documentation: <https://geo.kangeo.org>


## Features

-   Creating Geospatial Packages
-   Creating Interactive Maps
-

## Usage
```Python
import kangeo
import os
```
